@@ -1218,16 +1218,15 @@ def probabilities_table(stats: pd.DataFrame, ensembles: pd.DataFrame, rperiods:
 
             data = geoglows.streamflow.probabilities_table(stats, ensembles, rperiods)
     """
-    dates = stats['datetime'].tolist()
+    dates = stats.index.tolist()
     startdate = dates[0]
     enddate = dates[-1]
-    start_datetime = datetime.datetime.strptime(startdate, "%Y-%m-%d %H:00:00")
-    span = datetime.datetime.strptime(enddate, "%Y-%m-%d %H:00:00") - start_datetime
-    uniqueday = [start_datetime + datetime.timedelta(days=i) for i in range(span.days + 2)]
+    span = enddate - startdate
+    uniqueday = [startdate + datetime.timedelta(days=i) for i in range(span.days + 2)]
     # get the return periods for the stream reach
-    rp2 = rperiods.iloc[3][0]
-    rp10 = rperiods.iloc[2][0]
-    rp20 = rperiods.iloc[1][0]
+    rp2 = rperiods['return_period_2'].values
+    rp10 = rperiods['return_period_10'].values
+    rp20 = rperiods['return_period_20'].values
 
     # fill the lists of things used as context in rendering the template
     days = []
